#
# spec file for package intel-hybrid-driver
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           intel-hybrid-driver
Version:        2.0.0
Release:        1.2
Summary:        VA driver for Intel G45 & HD Graphics family
License:        MIT
URL:            https://github.com/intel/intel-hybrid-driver
Source0:        %{url}/archive/1.0.2/%{name}-1.0.2.tar.gz
Patch1:         intel-hybrid-codec-driver-2.0.0-gcc10-fix.patch
Patch2:         intel-hybrid-codec-driver-2.0.0-invalid-read-fix.patch
Patch3:         intel-hybrid-codec-driver-2.0.0-nullptr-fix.patch
Patch4:         intel-hybrid-codec-driver-2.0.0-vadriverinit-fix.patch
Patch5:         intel-hybrid-codec-driver-2.0.0-x11-fix.patch

BuildRequires:  c++_compiler
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libcmrt) >= 0.10.0
BuildRequires:  pkgconfig(libdrm) >= 2.4.45
BuildRequires:  pkgconfig(libva) >= 1.0.0
BuildRequires:  pkgconfig(libva-wayland)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(wayland-client)
# Obviously only for intel platform
ExclusiveArch:  %{ix86} x86_64 ia64

%description
This is the VA-API implementation for Intel G45 chipsets
and Intel HD Graphics for Intel Core processor family.

%prep
%autosetup -p1 -n %{name}-1.0.2

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
	--enable-drm \
	--enable-x11 \
	--enable-wayland \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS README
%dir %{_libdir}/dri
%{_libdir}/dri/hybrid_drv_video.so

%changelog
* Mon Jan  6 2025 Stefan Dirsch <sndirsch@suse.com>
- fixed source URL in specfile
* Fri Jan  3 2025 Stefan Dirsch <sndirsch@suse.com>
- fixed driver for current libva by switchting to gentoo patches
  (boo#1234858)
  * intel-hybrid-codec-driver-2.0.0-gcc10-fix.patch
  * intel-hybrid-codec-driver-2.0.0-invalid-read-fix.patch
  * intel-hybrid-codec-driver-2.0.0-nullptr-fix.patch
  * intel-hybrid-codec-driver-2.0.0-vadriverinit-fix.patch
  * intel-hybrid-codec-driver-2.0.0-x11-fix.patch
- supersedes the following patches
  * U_Update-the-dependency-to-libva-2.0.patch
  * n_libva-2.0-ABI-header-fix.patch
  * u_gcc10.patch
- raised driver version number to 2.0.0
* Tue Jun  9 2020 Stefan Dirsch <sndirsch@suse.com>
- u_gcc10.patch
  * fixes build against gcc10, which uses -fno-common as default
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update URL to current home.
- Replace gcc-c++ with generic c++_compiler BuildRequires.
- Drop Group tag.
- Pass autogen.sh to bootstrap instead of manually calling
  autoreconf.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Add n_libva-2.0-ABI-header-fix.patch: Load libva-x11.so.2 for
  libva-2.0 ABI version. This is a reworked patch from an upstream
  merge request. Patch in it's current form is not upstreamable,
  but works for us since we only have libva-2.0 to care about.
  See https://github.com/01org/intel-hybrid-driver/pull/26 for more
  context.
* Sat Jan 26 2019 bjorn.lie@gmail.com
- Add U_Update-the-dependency-to-libva-2.0.patch: Update the
  dependency to libva 2.0. In addition, this fixes deprecated
  warning caused by libva 2.0.
- Add Group tag and use macros in spec for building.
* Thu Sep 21 2017 sndirsch@suse.com
- fixed build on Leap (apparently there is no %%make_build macro yet)
* Fri Aug 18 2017 zaitor@opensuse.org
- Initial packaging for openSUSE, version 1.0.2.
